@@ -1,5 +1,5 @@
 /* archimedes.c -- This code is a simulator for Submicron 2D Silicon/GaAs
-   Devices. It implements the Monte Carlo method
+   Devices. It implements the Monte Carlo method and MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -24,9 +24,9 @@
 
 // =================================================================
 // File Name : mainArchimedes.c
-// Version   : release 0.0.2
+// Version   : release 0.0.3
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 19 Feb.2005, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 16 Mar.2005, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -58,6 +58,9 @@
 #define MCE 0  // MCE stands for MC for electrons only
 #define MCH 1  // MCH stands for MC for holes only
 #define MCEH 2 // MCEH stands for MC both for electrons and holes
+#define MEPE 3 // MEPE stands for MEP model for electrons only
+#define MEPH 4 // MEPH stands for MEP model for holes only
+#define MEPEH 5 // MEPEH stands for MEP model for electrons and holes
 #define GNUPLOTFORMAT 0 // output file in GNUPLOT format
 #define MESHFORMAT 1 // output file in Mesh format
 #define SILICON 0 // flag for Silicon material
@@ -65,6 +68,10 @@
 
 // ===============================
 #include "constants.h"
+#include "extrema.h"
+#include "sign.h"
+#include "mm.h"
+#include "mm2.h"
 #include "definitionoffunctions.h"
 // ===============================
 
@@ -74,9 +81,11 @@ int SAVEALWAYS;
 int nx,ny;
 int ISEED,NP1,INUM,IV;
 int c,Model_Number,File_Format,Material,Quantum_Flag;
+int leid_flag;
 
 // All "real"'s here...
-real u2d[NXM+1][NYM+1][MN3+1],h2d[NXM+1][NYM+1][2];
+real u2d[NXM+1][NYM+1][MN3+1];
+real h2d[NXM+1][NYM+1][MN3+1];
 real PSI[NXM+1][NYM+1],E[NXM+1][NYM+1][2];
 real N_D[NXM+1][NYM+1],N_H[NXM+1][NYM+1];
 real dx,dy;
@@ -89,11 +98,21 @@ real SWK[3][14][DIME+1];
 real P[NPMAX+1][7],AF[3],EC[3];
 real KX,KY,KZ,X,Y;
 real TS,EPP,DDmax;
-real EDGE[4][NXM+NYM+1][3];
+real EDGE[4][NXM+NYM+1][4];
 real alphaMATERIAL;
 real epsMATERIAL;
-real CIMP,QD2;
+real CIMP,QD2,TAUW;
 real DG[NXM+1][NYM+1],DL[NXM+1][NYM+1];
+real bufx2d[NXM+1][NYM+1];
+real bufy2d[NXM+1][NYM+1];
+real ux2d[NXM+1][NYM+1][MN3+1];
+real uy2d[NXM+1][NYM+1][MN3+1];
+real f2d[NXM+1][NYM+1][MN3+1];
+real g2d[NXM+1][NYM+1][MN3+1];
+real fx2d[NXM+1][NYM+1][MN3+1];
+real gy2d[NXM+1][NYM+1][MN3+1];
+real c11[7],c12[7],c21[7],c22[7];
+real u[7],f[7],g[7],cw[7];
 
 // All structures here...
 time_t binarytime;
@@ -215,6 +234,10 @@ For more information about these matters, see the file named COPYING.\n",
 // =========================
      fclose(fp);
 
+// Read all the coefficients for MEP simulation
+// ============================================
+     MEP_coefficients();
+
 // Loading of the initial runtime
 // ==============================
      binarytime=time(NULL);
@@ -258,7 +281,7 @@ For more information about these matters, see the file named COPYING.\n",
 // ****************************************************
 
 // =======================================================
-// Modif. 06 ago.2004 - 05 Oct.2004, Siracusa, J.M.Sellier
+// Modif. 06 ago.2004 - 04 Mar.2005, Siracusa, J.M.Sellier
 // =======================================================
 #include "poissonbcs.h"
 #include "media.h"
@@ -280,6 +303,13 @@ For more information about these matters, see the file named COPYING.\n",
 #include "updating.h"
 #include "readinputfile.h"
 #include "computecurrents.h"
+#include "electron_relaxation.h"
+#include "ParabMEP2D.h"
+#include "HMEPbcs.h"
+#include "MEP_interpolation.h"
+#include "holemep2d.h"
+#include "hole_relaxation.h"
+#include "Hole_bcs.h"
 // =========================================
 
 /* archimedes.c ends here */
