@@ -1,6 +1,6 @@
-/* constants.h -- This file is part of Archimedes release 0.0.2.
+/* constants.h -- This file is part of Archimedes release 0.0.3.
    Archimedes is a simulator for Submicron 2D Silicon/GaAs
-   Devices. It implements both the Monte Carlo method
+   Devices. It implements both the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 5 aug.2004, Siracusa, J.M.Sellier
-// Last modif. : 11 jan.2005, Siracusa, J.M.Sellier
+// Last modif. : 04 mar.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Universal Physical Constants in M.K.S.C. system
@@ -35,7 +35,7 @@
 
 // Boltzmann constant (Joule/Kelvin)
  const real KB=1.380658e-23;
- // Electron charge in absolute value (Coulomb)
+// Electron charge in absolute value (Coulomb)
  const real Q=1.60217733e-19;
 // Reduced Planck constant (Joule*sec)
  const real HBAR=1.05457266e-34;
@@ -101,6 +101,17 @@
  real E_MIN_GAMMA=0.;
 // Energy minimum of L-valley (eV)
  real E_MIN_L=0.29;
-      
+// Silicon low field mobility (m^2/(V*sec))
+ real MIU0=1400.e-4;
+// Silicon saturation velocity (m/sec)
+ real VS=1.e5;
+// Silicon heavy hole effective mass
+ real mstarhole=0.57;
+// Silicon heavy hole low field mobility (m^2/(V*sec))
+ real MIU0hole=0.0471;
+// Silicon heavy hole saturation velocity (m/sec)
+ real VShole=1.e5;
+// Silicon Schottky contact density (1/m^3)
+ real NGATE=3.9e11;
 // ######################################################
 // ######################################################
