@@ -1,6 +1,6 @@
-/* definitionoffunctions.h -- This file is part of Archimedes release 0.0.1.
-   Archimedes is a simulator for Submicron 2D Silicon
-   Devices. It implements both the Monte Carlo method
+/* definitionoffunctions.h -- This file is part of Archimedes release 0.0.3.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+   Devices. It implements both the Monte Carlo method and MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -24,7 +24,7 @@
 
 // ######################################################
 // Created on 21 Sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 05 Oct.2004, Siracusa, J.M.Sellier
+// Last modif. : 04 Mar.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Definition of all the functions used in Archimedes
@@ -48,6 +48,22 @@ void Charge(void);
 void updating(int);
 void Read_Input_File(void);
 void Compute_Currents(void);
+void electron_relaxation_step(void);
+void ParabMEP2D(int,int,real,real,real,real);
+void HMEPBCs(void);
+void MEP_coefficients(void);
+void Hole_MEP2D(int,int,real,real,real,real);
+void HoleHMEPBCs(void);
+void Relaxation_Step_Hole(void);
 real rnd(void);
+real c11i(real);
+real c12i(real);
+real c21i(real);
+real c22i(real);
+real Ui(real);
+real Fi(real);
+real Gi(real);
+real cwi(real);
+real tauwi(real);
 
 // =============================================
