@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 05 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 19 Feb.2005, Siracusa, J.M.Sellier
+// Last modif. : 16 Mar.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Initial Configuration of the Particles (electrons)
@@ -45,6 +45,7 @@ MCdevice_config(void)
    for(j=1;j<=ny+1;j++){
 // np=number of particles in the (i,j)-th cell
      np=(int)(N_D[i][j]*dx*dy/EPP+0.5);
+     if(leid_flag==1) np=(int)(u2d[i][j][1]*dx*dy/EPP+0.5);
      if((i==1) || (i==nx+1)) np/=2;
      if((j==1) || (j==ny+1)) np/=2;
      if(np>0){
@@ -57,19 +58,39 @@ MCdevice_config(void)
 // We assume that the particles are initially 
 // at near thermal equilibrium
 
-// In the case of GaAs all the electrons are considered in the Gamma
-// valley in the starting simulation time.
-
-      IV=1;
-      c1=log(rnd());
-      if(Material==SILICON) 
-       c2=SMH[0]*sqrt(-1.5*BKTQ*c1*(1.-alphaSILICON*1.5*BKTQ*c1));
-      if(Material==GAAS){
+// In the case of GaAs, 80% of the electrons are considered in the Gamma
+// valley in the starting simulation time, while the other 20% are
+// in the L-valley.
+      if(leid_flag==0){
        IV=1;
-       c2=SMH[IV]*sqrt(-1.5*BKTQ*c1*(1.-alphaGAAS*1.5*BKTQ*c1));
-       if(rnd()>0.8){
-        IV=2;
-        c2=SMH[IV]*sqrt(-1.5*BKTQ*c1*(1.-alpha2GAAS*1.5*BKTQ*c1));
+       c1=log(rnd());
+       if(Material==SILICON) 
+        c2=SMH[0]*sqrt(-1.5*BKTQ*c1*(1.-alphaSILICON*1.5*BKTQ*c1));
+       if(Material==GAAS){
+        IV=1;
+        c2=SMH[IV]*sqrt(-1.5*BKTQ*c1*(1.-alphaGAAS*1.5*BKTQ*c1));
+        if(rnd()>0.8){
+         IV=2;
+         c2=SMH[IV]*sqrt(-1.5*BKTQ*c1*(1.-alpha2GAAS*1.5*BKTQ*c1));
+        }
+       }
+      }
+// The following is in case of precendtly loaded initial data.
+      if(leid_flag==1){
+       IV=1;
+// In this case c1 represents the mean electron energy
+// loaded from precedent simulations and have nothing to 
+// do with the lattice energy.
+       c1=-u2d[i][j][4]/u2d[i][j][1]/Q;
+       if(Material==SILICON) 
+        c2=SMH[0]*sqrt(-1.5*c1*(1.-alphaSILICON*1.5*c1));
+       if(Material==GAAS){
+        IV=1;
+        c2=SMH[IV]*sqrt(-1.5*c1*(1.-alphaGAAS*1.5*c1));
+        if(rnd()>0.8){
+         IV=2;
+         c2=SMH[IV]*sqrt(-1.5*c1*(1.-alpha2GAAS*1.5*c1));
+        }
        }
       }
       c3=1.-2.*rnd();
