@@ -1,6 +1,6 @@
-/* readinputfile.h -- This file is part of Archimedes release 0.0.2.
+/* readinputfile.h -- This file is part of Archimedes release 0.0.3.
    Archimedes is a simulator for Submicron 2D Silicon/GaAs
-   Devices. It implements the Monte Carlo method
+   Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -25,13 +25,13 @@
 
 // ######################################################
 // Created on 10 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 27 jan.2005, Siracusa, J.M.Sellier
+// Last modif. : 16 mar.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Read the geometrical and physical description of the device.
-// The input file is interpreted like a "computer language".
+// The input file is interpreted as in a script language.
 // For the syntax of the commands of this language see
-// the manual GNU Archimedes release 0.0.1
+// the manual GNU Archimedes release 0.0.3
 
 void
 Read_Input_File(void)
@@ -41,6 +41,7 @@ Read_Input_File(void)
  int ini,fin;
  int i,j;
  int LXflag=0, LYflag=0;
+ int transportflag=0;
  
 // Thess are the default values
 // i.e. if nothing is specified
@@ -53,6 +54,7 @@ Read_Input_File(void)
  ny=50; // default # of cells in y-direction
  TF=5.0e-12; // Default Final Time in seconds
  DT=0.001e-12; // Default constant time step
+ TAUW=0.4e-12; // Default Energy relaxation time
  mstar=mstarSILICON; // coefficient of the Si elettronic effective mass
  msh=mstarHSILICON; // coefficient of the Si heavy hole effective mass
 // standard doping concentration
@@ -60,7 +62,8 @@ Read_Input_File(void)
    for(j=1;j<=ny+1;j++){
       u2d[i][j][1]=N_D[i][j]=NI;
       h2d[i][j][1]=N_H[i][j]=NI;
-      u2d[i][j][2]=u2d[i][j][3]=u2d[i][j][4]=0.;
+      u2d[i][j][2]=u2d[i][j][3]=0.;
+      h2d[i][j][2]=h2d[i][j][3]=0.;
    }
  CIMP=1.e20; // Impurity concentration
  TL=300.; // Lattice temperature in Kelvin
@@ -70,6 +73,7 @@ Read_Input_File(void)
  MAXIMINI=0; // No computation of max and min of variables during simulation
  SAVEALWAYS=0; // we don't save at each step by default
  File_Format=GNUPLOTFORMAT; // output file in mesh format
+ leid_flag=0;
 // =====================
 
 // Reading the input file
@@ -113,26 +117,53 @@ Processing the input file\n\
   }
 // here we choose the charge particle transport simulated
   else if(strcmp(s,"TRANSPORT")==0){
+    transportflag=1;
     fscanf(fp,"%s",s);
-    if(strcmp(s,"ELECTRONS")==0){
-      Model_Number=MCE;
-      printf("TRANSPORT %s ---> Ok\n",s);
+    if(strcmp(s,"MC")==0){
+      fscanf(fp,"%s",s);
+      if(strcmp(s,"ELECTRONS")==0){
+        Model_Number=MCE;
+        printf("TRANSPORT MC %s ---> Ok\n",s);
+      }
+      else if(strcmp(s,"HOLES")==0){
+        Model_Number=MCH;
+        printf("TRANSPORT %s ---> Ok\n",s);
+        printf("%s: hole transport not yet implemented\n",progname);
+        exit(EXIT_FAILURE);
+      }
+      else if(strcmp(s,"BIPOLAR")==0){
+        Model_Number=MCEH;
+        printf("TRANSPORT MC %s ---> Ok\n",s);
+      }
+      else{
+        printf("\
+%s: unknown particles in MC transport specification\n",progname);
+        exit(EXIT_FAILURE);
+      }
     }
-    else if(strcmp(s,"HOLES")==0){
-      Model_Number=MCH;
-      printf("TRANSPORT %s ---> Ok\n",s);
-      printf("%s: hole transport not yet implemented\n",progname);
-      exit(EXIT_FAILURE);
-    }
-    else if(strcmp(s,"BIPOLAR")==0){
-      Model_Number=MCEH;
-      printf("TRANSPORT %s ---> Ok\n",s);
-      printf("%s: bipolar transport not yet implemented\n",progname);
-      exit(EXIT_FAILURE);
+    else if(strcmp(s,"MEP")==0){
+      fscanf(fp,"%s",s);
+      if(strcmp(s,"ELECTRONS")==0){
+        Model_Number=MEPE;
+        printf("TRANSPORT MEP %s ---> Ok\n",s);
+      }
+      else if(strcmp(s,"HOLES")==0){
+        Model_Number=MEPH;
+        printf("TRANSPORT %s ---> Ok\n",s);
+      }
+      else if(strcmp(s,"BIPOLAR")==0){
+        Model_Number=MEPEH;
+        printf("TRANSPORT %s ---> Ok\n",s);
+      }
+      else{
+        printf("\
+%s: unknown particles in MEP transport specification\n",progname);
+        exit(EXIT_FAILURE);
+      }
     }
     else{
-      printf("%s: unknown transport specification\n",progname);
-      exit(EXIT_FAILURE);
+        printf("\%s: unknown transport model specified\n",progname);
+        exit(EXIT_FAILURE);
     }
   }
 // Specified the number of spatial step in x direction
@@ -175,6 +206,16 @@ Processing the input file\n\
     }
     printf("FINAL TIME = %g ---> Ok\n",TF);
   }
+// setting the energy relaxation time
+  else if(strcmp(s,"TAUW")==0){
+    fscanf(fp,"%Lg",&num);
+    TAUW=num;
+    if(TAUW==0.){
+      printf("%s: not valid energy relaxation time\n",progname);
+      exit(EXIT_FAILURE);
+    }
+    printf("TAUW = %g ---> Ok\n",TAUW);
+  }
 // configuration of the time step
   else if(strcmp(s,"TIMESTEP")==0){
     fscanf(fp,"%Lg",&num);
@@ -185,6 +226,66 @@ Processing the input file\n\
     }
     printf("TIME STEP = %g ---> Ok\n",DT);
   }
+// load electron initial data ___ LEID = Load Electron Initial Data
+  else if(strcmp(s,"LEID")==0){
+    FILE *dp;
+    FILE *pp;
+    FILE *ep;
+    long double dum,dum0,dum1;
+// Open the initial electron density file
+    dp=fopen("density_start.xyz","r");
+// File Control, just in case the file does not exist...
+     if(dp==NULL){
+      printf("\
+%s: fatal error in opening the density000.xyz input file\n",progname);
+      exit(EXIT_FAILURE);
+     }
+// Open the initial electron energy file
+    ep=fopen("energy_start.xyz","r");
+// File Control, just in case the file does not exist...
+     if(ep==NULL){
+      printf("\
+%s: fatal error in opening the energy000.xyz input file\n",progname);
+      exit(EXIT_FAILURE);
+     }
+// Open the initial potential file
+    pp=fopen("potential_start.xyz","r");
+// File Control, just in case the file does not exist...
+     if(pp==NULL){
+      printf("\
+%s: fatal error in opening the potential000.xyz input file\n",progname);
+      exit(EXIT_FAILURE);
+     }
+// Load the initial data for electrons in case of Monte Carlo method
+    if(Model_Number==MCE || Model_Number==MCEH){
+      for(j=1;j<=ny+1;j++)
+       for(i=1;i<=nx+1;i++){
+        fscanf(dp,"%Lf %Lf %Lf",&dum0,&dum1,&dum);
+        u2d[i][j][1]=(real)(dum);
+        fscanf(ep,"%Lf %Lf %Lf",&dum0,&dum1,&dum);
+        u2d[i][j][4]=(real)(dum*Q*u2d[i][j][1]);
+        fscanf(pp,"%Lf %Lf %Lf",&dum0,&dum1,&dum);
+        PSI[i][j]=(real)(dum);
+       }
+    }
+// Load the initial data for electrons in case of Simplified MEP model
+    if(Model_Number==MEPE || Model_Number==MEPEH){
+      for(j=1;j<=ny+1;j++)
+       for(i=1;i<=nx+1;i++){
+        fscanf(dp,"%Lf %Lf %Lf",&dum0,&dum1,&dum);
+        u2d[i+2][j+2][1]=(real)(dum);
+        fscanf(ep,"%Lf %Lf %Lf",&dum0,&dum1,&dum);
+        u2d[i+2][j+2][4]=(real)(dum*Q*u2d[i+2][j+2][1]);
+        fscanf(pp,"%Lf %Lf %Lf",&dum0,&dum1,&dum);
+        PSI[i][j]=(real)(dum);
+       }
+    }
+    fclose(dp);
+    fclose(ep);
+    fclose(pp);
+    leid_flag=1;
+    printf("Electron initial data loaded ---> Ok\n");
+  }
 // choice of the GaAs impurity concentration
   else if(strcmp(s,"CIMP")==0){
     fscanf(fp,"%Lg",&num);
@@ -221,6 +322,10 @@ Processing the input file\n\
 // read the donor doping density
   else if(strcmp(s,"DONORDENSITY")==0){
     real xmin,ymin,xmax,ymax,conc;
+    if(transportflag==0){
+      printf("%s: you have to specify a transport model first\n",progname);
+      exit(EXIT_FAILURE);
+    }
 // read and check the xmin value
     fscanf(fp,"%Lg",&num);
     xmin=num;
@@ -256,11 +361,22 @@ Processing the input file\n\
       printf("%s: not valid donor density\n",progname);
       exit(EXIT_FAILURE);
     }
+    if(Model_Number==MCE || Model_Number==MCEH)
     for(i=1;i<=nx+1;i++)
       for(j=1;j<=ny+1;j++)
         if((i-0.5)*dx>=xmin && (i-1.5)*dx<=xmax
-         &&(j-0.5)*dy>=ymin && (j-1.5)*dy<=ymax)
-          u2d[i][j][1]=N_D[i][j]=conc;
+         &&(j-0.5)*dy>=ymin && (j-1.5)*dy<=ymax){
+           u2d[i][j][1]=N_D[i][j]=conc;
+        }
+    if(Model_Number==MEPE || Model_Number==MEPEH || Model_Number==MEPH)
+    for(i=1;i<=nx+1;i++)
+      for(j=1;j<=ny+1;j++){
+        if((i-0.5)*dx>=xmin && (i-1.5)*dx<=xmax
+         && (j-0.5)*dy>=ymin && (j-1.5)*dy<=ymax){
+           u2d[i+2][j+2][1]=N_D[i][j]=conc;
+           u2d[i+2][j+2][4]=conc*1.5*KB*TL;
+        }
+      }
     printf("DONOR DENSITY %g %g %g %g %g ---> Ok\n",
            xmin,ymin,xmax,ymax,conc);
   }
@@ -303,13 +419,15 @@ Processing the input file\n\
       printf("%s: not valid acceptor density\n",progname);
       exit(EXIT_FAILURE);
     }
-    for(i=1;i<=nx;i++)
-      for(j=1;j<=ny;j++)
+    if(Model_Number==MEPEH || Model_Number==MEPH || Model_Number==MCEH)
+    for(i=1;i<=nx+1;i++)
+      for(j=1;j<=ny+1;j++){
         if((i-0.5)*dx>=xmin && (i-1.5)*dx<=xmax
-         &&(j-0.5)*dy>=ymin && (j-1.5)*dy<=ymax)
-          h2d[i][j][1]=N_H[i][j]=conc;
-    printf("ACCEPTOR DENSITY %g %g %g %g %g ---> Ok\n",
-           xmin,ymin,xmax,ymax,conc);
+         && (j-0.5)*dy>=ymin && (j-1.5)*dy<=ymax){
+           h2d[i+2][j+2][1]=N_H[i][j]=conc;
+           h2d[i+2][j+2][4]=conc*1.5*KB*TL;
+        }
+      }
   }
 // read the lattice temperature
   else if(strcmp(s,"LATTICETEMPERATURE")==0){
@@ -346,7 +464,7 @@ Processing the input file\n\
 // Definition of an eventual contact
   else if(strcmp(s,"CONTACT")==0){
     char pos[80],kind[80];
-    real ipos,fpos,delt,dens;
+    real ipos,fpos,delt,dens,denshole;
     real potential;
     int i,j,k;
 // read and check the "qualitative" position of the contact
@@ -400,6 +518,13 @@ Processing the input file\n\
       fscanf(fp,"%Lg",&num);
       dens=num;
     }
+// read the hole density for the reservoir at contact
+// if and only if the contact is ohmic
+    if(k==2 && (Model_Number==MCH || Model_Number==MEPH
+                   || Model_Number==MCEH || Model_Number==MEPEH)){
+      fscanf(fp,"%Lg",&num);
+      denshole=num;
+    }
 // internal definition of the boundary conditions
 // EDGE[i][j][k] = ref
 // i = 0 BOTTOM EDGE
@@ -415,6 +540,8 @@ Processing the input file\n\
 // ref is the applied potential reference
 // k = 2
 // ref is the density of electron reservoirs at the contact
+// k = 3
+// ref is the density of hole reservoirs at the contact
     ini=(int)(ipos/delt)+1;
     fin=(int)(fpos/delt)+2;
     for(j=ini;j<=fin;j++){
@@ -422,19 +549,30 @@ Processing the input file\n\
       if(k==0 || k==1){
         EDGE[i][j][1]=potential;
         EDGE[i][j][2]=0;
+        if(k==1) EDGE[i][j][2]=NGATE;
+        if(k==1 && (Model_Number==MCH || Model_Number==MEPH
+                   || Model_Number==MCEH || Model_Number==MEPEH))
+          EDGE[i][j][3]=NI*NI/NGATE;
       }
       else if(k==2){
         EDGE[i][j][1]=potential;
         EDGE[i][j][2]=dens;
+        if(Model_Number==MCH || Model_Number==MEPH
+          || Model_Number==MCEH || Model_Number==MEPEH)
+         EDGE[i][j][3]=denshole;
       }
     }
 
 // Then everything is ok in the contact definition...
     if(k!=2)printf("CONTACT %s %g %g %s %g ---> Ok\n",
             pos,ipos,fpos,kind,potential);
-    else if(k==2)printf("CONTACT %s %g %g %s %g %g ---> Ok\n",
+    else if(k==2){
+     printf("CONTACT %s %g %g %s %g %g ",
             pos,ipos,fpos,kind,potential,dens);
-
+     if(Model_Number==MCH || Model_Number==MEPH
+        || Model_Number==MCEH || Model_Number==MEPEH) printf("%g ",denshole);
+     printf("---> Ok\n");
+    }
   }
   else if(strcmp(s,"NOQUANTUMEFFECTS")==0){
     Quantum_Flag=0;
