@@ -1,6 +1,6 @@
-/* saveoutput2dgnuplot.h -- This file is part of Archimedes release 0.0.2.
-   Archimedes is a simulator for Submicron 2D Silicon
-   Devices. It implements the Monte Carlo method
+/* saveoutput2dgnuplot.h -- This file is part of Archimedes release 0.0.3.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+   Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 10 Sep.2004, Siracusa (Italy), J.M.Sellier
-// Last modif. : 19 Feb.2005, Siracusa (Italy), J.M.Sellier
+// Last modif. : 01 Mar.2005, Siracusa (Italy), J.M.Sellier
 // ######################################################
 
 // Here we save all the macroscopic variables 
@@ -122,78 +122,155 @@ if(Material==SILICON){
    sprintf(s,"quantum_potential%d.xyz",je);
    qp=fopen(s,"w");
  }
-
+// Save the Monte Carlo results
+ if(Model_Number==MCE || Model_Number==MCEH){
 // Electron Density Output
 // =======================
- for(j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(fp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,u2d[i][j][1]);
-     fprintf(fp,"\n");
- }
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(fp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,u2d[i][j][1]);
+      fprintf(fp,"\n");
+  }
 // X-component of electronic velocity output
 // =========================================
- for(j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(up,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
-             u2d[i][j][2]/MEDIA);
-     fprintf(up,"\n");
- }
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(up,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
+              u2d[i][j][2]/MEDIA);
+      fprintf(up,"\n");
+  }
 // Y-component of electronic velocity output
 // =========================================
- for (j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(vp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
-             u2d[i][j][3]/MEDIA);
-     fprintf(vp,"\n");
- }
+  for (j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(vp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
+              u2d[i][j][3]/MEDIA);
+      fprintf(vp,"\n");
+  }
 // Electrostatic Potential
 // =======================
- for(j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(lp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,PSI[i][j]);
-     fprintf(lp,"\n");
- }
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(lp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,PSI[i][j]);
+      fprintf(lp,"\n");
+  }
 // X-component of electric field
 // =============================
- for(j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(lxp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,E[i][j][0]);
-     fprintf(lxp,"\n");
- }
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(lxp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,E[i][j][0]);
+      fprintf(lxp,"\n");
+  }
 // Y-component of electric field
 // =============================
- for(j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(lyp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,E[i][j][1]);
-     fprintf(lyp,"\n");
- }
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(lyp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,E[i][j][1]);
+      fprintf(lyp,"\n");
+  }
 // Electron Energy (in eV)
 // ===============
- for(j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(ep,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
-             u2d[i][j][4]/MEDIA);
-     fprintf(ep,"\n");
- }
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(ep,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
+              u2d[i][j][4]/MEDIA);
+      fprintf(ep,"\n");
+  }
 // Quantum Effective Potential
 // ===========================
- for(j=1;j<=ny+1;j++){
-   for(i=1;i<=nx+1;i++)
-     fprintf(qp,"%g %g %g\n",
-         1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,u2d[i][j][0]);
-     fprintf(qp,"\n");
- }
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(qp,"%g %g %g\n",
+          1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,u2d[i][j][0]);
+      fprintf(qp,"\n");
+  }
 
 // Closure of output files
 // =======================
- fclose(fp);
- fclose(up);
- fclose(vp);
- fclose(lp);
- fclose(lxp);
- fclose(lyp);
- fclose(ep);
- fclose(qp);
+   fclose(fp);
+   fclose(up);
+   fclose(vp);
+   fclose(lp);
+   fclose(lxp);
+   fclose(lyp);
+   fclose(ep);
+   fclose(qp);
+  }
+// Save the Hybrid MEP results
+ if(Model_Number==MEPE || Model_Number==MEPEH){
+// Electron Density Output
+// =======================
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(fp,"%g %g %g\n",1.e6*(i-1.)*dx,
+              1.e6*(j-1.)*dy,u2d[i+2][j+2][1]);
+      fprintf(fp,"\n");
+  }
+// X-component of electronic velocity output
+// =========================================
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(up,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
+              u2d[i+2][j+2][2]/u2d[i+2][j+2][1]);
+      fprintf(up,"\n");
+  }
+// Y-component of electronic velocity output
+// =========================================
+  for (j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(vp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
+              u2d[i+2][j+2][3]/u2d[i+2][j+2][1]);
+      fprintf(vp,"\n");
+  }
+// Electrostatic Potential
+// =======================
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(lp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,PSI[i][j]);
+      fprintf(lp,"\n");
+  }
+// X-component of electric field
+// =============================
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(lxp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,E[i][j][0]);
+      fprintf(lxp,"\n");
+  }
+// Y-component of electric field
+// =============================
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(lyp,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,E[i][j][1]);
+      fprintf(lyp,"\n");
+  }
+// Electron Energy (in eV)
+// ===============
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(ep,"%g %g %g\n",1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,
+              u2d[i+2][j+2][4]/u2d[i+2][j+2][1]/Q);
+      fprintf(ep,"\n");
+  }
+// Quantum Effective Potential
+// ===========================
+  for(j=1;j<=ny+1;j++){
+    for(i=1;i<=nx+1;i++)
+      fprintf(qp,"%g %g %g\n",
+          1.e6*(i-1.)*dx,1.e6*(j-1.)*dy,u2d[i][j][0]);
+      fprintf(qp,"\n");
+  }
+
+// Closure of output files
+// =======================
+   fclose(fp);
+   fclose(up);
+   fclose(vp);
+   fclose(lp);
+   fclose(lxp);
+   fclose(lyp);
+   fclose(ep);
+   fclose(qp);
+  }
  }
 // ****************************************************************
 if(Material==GAAS){
