@@ -1,7 +1,7 @@
 /* saveoutput2dholegnuplot.h --
-   This file is part of Archimedes release 0.0.1.
-   Archimedes is a simulator for Submicron 2D Silicon
-   Devices. It implements the Monte Carlo method
+   This file is part of Archimedes release 0.0.3.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+   Devices. It implements the Monte Carlo method and MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -26,7 +26,7 @@
 
 // ######################################################
 // Created on 10 Sep.2004, Siracusa (Italy), J.M.Sellier
-// Last modif. : 03 Oct.2004, Siracusa (Italy), J.M.Sellier
+// Last modif. : 05 Mar.2005, Siracusa (Italy), J.M.Sellier
 // ######################################################
 
 // Here we save all the macroscopic variables 
@@ -53,57 +53,57 @@ SaveOutput2DHoleGNUPLOT(int je)
  register int i,j;
 
  if(je<=9){
-   sprintf(s,"hole_density00%d.dat",je);
+   sprintf(s,"hole_density00%d.xyz",je);
    fp=fopen(s,"w");
-   sprintf(s,"hole_x_velocity00%d.dat",je);
+   sprintf(s,"hole_x_velocity00%d.xyz",je);
    up=fopen(s,"w");
-   sprintf(s,"hole_y_velocity00%d.dat",je);
+   sprintf(s,"hole_y_velocity00%d.xyz",je);
    vp=fopen(s,"w");
-   sprintf(s,"hole_energy00%d.dat",je);
+   sprintf(s,"hole_energy00%d.xyz",je);
    ep=fopen(s,"w");
-   sprintf(s,"potential00%d.dat",je);
+   sprintf(s,"potential00%d.xyz",je);
    lp=fopen(s,"w");
-   sprintf(s,"x_Efield00%d.dat",je);
+   sprintf(s,"x_Efield00%d.xyz",je);
    lxp=fopen(s,"w");
-   sprintf(s,"y_Efield00%d.dat",je);
+   sprintf(s,"y_Efield00%d.xyz",je);
    lyp=fopen(s,"w");
-   sprintf(s,"quantum_potential00%d.dat",je);
+   sprintf(s,"quantum_potential00%d.xyz",je);
    qp=fopen(s,"w");
  }
  else if(je>9 && je<=99){
-   sprintf(s,"hole_density0%d.dat",je);
+   sprintf(s,"hole_density0%d.xyz",je);
    fp=fopen(s,"w");
-   sprintf(s,"hole_x_velocity0%d.dat",je);
+   sprintf(s,"hole_x_velocity0%d.xyz",je);
    up=fopen(s,"w");
-   sprintf(s,"hole_y_velocity0%d.dat",je);
+   sprintf(s,"hole_y_velocity0%d.xyz",je);
    vp=fopen(s,"w");
-   sprintf(s,"hole_energy0%d.dat",je);
+   sprintf(s,"hole_energy0%d.xyz",je);
    ep=fopen(s,"w");
-   sprintf(s,"potential0%d.dat",je);
+   sprintf(s,"potential0%d.xyz",je);
    lp=fopen(s,"w");
-   sprintf(s,"x_Efield0%d.dat",je);
+   sprintf(s,"x_Efield0%d.xyz",je);
    lxp=fopen(s,"w");
-   sprintf(s,"y_Efield0%d.dat",je);
+   sprintf(s,"y_Efield0%d.xyz",je);
    lyp=fopen(s,"w");
-   sprintf(s,"quantum_potential0%d.dat",je);
+   sprintf(s,"quantum_potential0%d.xyz",je);
    qp=fopen(s,"w");
  }
  else{
-   sprintf(s,"hole_density%d.dat",je);
+   sprintf(s,"hole_density%d.xyz",je);
    fp=fopen(s,"w");
-   sprintf(s,"hole_x_velocity%d.dat",je);
+   sprintf(s,"hole_x_velocity%d.xyz",je);
    up=fopen(s,"w");
-   sprintf(s,"hole_y_velocity%d.dat",je);
+   sprintf(s,"hole_y_velocity%d.xyz",je);
    vp=fopen(s,"w");
-   sprintf(s,"hole_energy%d.dat",je);
+   sprintf(s,"hole_energy%d.xyz",je);
    ep=fopen(s,"w");
-   sprintf(s,"potential%d.dat",je);
+   sprintf(s,"potential%d.xyz",je);
    lp=fopen(s,"w");
-   sprintf(s,"x_Efield%d.dat",je);
+   sprintf(s,"x_Efield%d.xyz",je);
    lxp=fopen(s,"w");
-   sprintf(s,"y_Efield%d.dat",je);
+   sprintf(s,"y_Efield%d.xyz",je);
    lyp=fopen(s,"w");
-   sprintf(s,"quantum_potential%d.dat",je);
+   sprintf(s,"quantum_potential%d.xyz",je);
    qp=fopen(s,"w");
  }
 
@@ -111,7 +111,8 @@ SaveOutput2DHoleGNUPLOT(int je)
 // =======================
  for(j=1;j<=ny+1;j++){
    for(i=1;i<=nx+1;i++)
-     fprintf(fp,"%g %g %g\n",1.e6*(i-0.5)*dx,1.e6*(j-0.5)*dy,h2d[i][j][1]);
+     fprintf(fp,"%g %g %g\n",
+             1.e6*(i-0.5)*dx,1.e6*(j-0.5)*dy,h2d[i+2][j+2][1]);
      fprintf(fp,"\n");
  }
 // X-component of electronic velocity output
@@ -119,7 +120,8 @@ SaveOutput2DHoleGNUPLOT(int je)
  for(j=1;j<=ny+1;j++){
    for(i=1;i<=nx+1;i++)
      fprintf(up,"%g %g %g\n",
-          1.e6*(i-0.5)*dx,1.e6*(j-0.5)*dy,h2d[i][j][2]/(h2d[i][j][1]+SMALL));
+          1.e6*(i-0.5)*dx,1.e6*(j-0.5)*dy,
+          h2d[i+2][j+2][2]/h2d[i+2][j+2][1]);
      fprintf(up,"\n");
  }
 // Y-component of electronic velocity output
@@ -127,7 +129,8 @@ SaveOutput2DHoleGNUPLOT(int je)
  for (j=1;j<=ny+1;j++){
    for(i=1;i<=nx+1;i++)
      fprintf(vp,"%g %g %g\n",
-          1.e6*(i-0.5)*dx,1.e6*(j-0.5)*dy,h2d[i][j][3]/(h2d[i][j][1]+SMALL));
+          1.e6*(i-0.5)*dx,1.e6*(j-0.5)*dy,
+          h2d[i+2][j+2][3]/h2d[i+2][j+2][1]);
      fprintf(vp,"\n");
  }
 // Electrostatic Potential
@@ -156,7 +159,8 @@ SaveOutput2DHoleGNUPLOT(int je)
  for(j=1;j<=ny+1;j++){
    for(i=1;i<=nx+1;i++)
      fprintf(ep,"%g %g %g\n",
-         1.e6*(i-0.5)*dx,1.e6*(j-0.5)*dy,h2d[i][j][4]/(h2d[i][j][1]+SMALL));
+         1.e6*(i-0.5)*dx,1.e6*(j-0.5)*dy,
+         h2d[i+2][j+2][4]/h2d[i+2][j+2][1]/Q);
      fprintf(ep,"\n");
  }
 // Quantum Effective Potential
