@@ -1,6 +1,6 @@
-/* saveoutput2dmeshformat.h -- This file is part of Archimedes release 0.0.2.
-   Archimedes is a simulator for Submicron 2D Silicon
-   Devices. It implements the Monte Carlo method
+/* saveoutput2dmeshformat.h -- This file is part of Archimedes release 0.0.3.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+   Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 24 Apr.2004, Siracusa, J.M.Sellier
-// Last modif. : 19 Feb.2004, Siracusa, J.M.Sellier
+// Last modif. : 01 Mar.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Here we save all the macroscopic variables 
@@ -152,7 +152,9 @@ else{
  fprintf(Xp,"%d %d %d %d\n",dim,nbmet,nbval,type);
  fprintf(Yp,"%d %d %d %d\n",dim,nbmet,nbval,type);
  fprintf(Qp,"%d %d %d %d\n",dim,nbmet,nbval,type);
- 
+
+// Save the Monte Carlo results 
+ if(Model_Number==MCE || Model_Number==MCEH){
 // Save the macroscopic variables related to electrons
 // ===================================================
    for(j=1;j<=ny+1;j++)
@@ -194,7 +196,51 @@ else{
      fprintf(mp,"%d %d %d %d 0\n",
          i+(j-1)*(nx+1),i+1+(j-1)*(nx+1),
          i+1+j*(nx+1),i+j*(nx+1)); // 1 2 4 3
+ }
+// Save the Hybrid MEP results 
+ if(Model_Number==MEPE || Model_Number==MEPEH){
+// Save the macroscopic variables related to electrons
+// ===================================================
+   for(j=1;j<=ny+1;j++)
+     for(i=1;i<=nx+1;i++)
+       fprintf(Qp,"%g\n",u2d[i][j][0]);
+   for(j=1;j<=ny+1;j++)
+     for(i=1;i<=nx+1;i++)
+       fprintf(pop,"%g\n",PSI[i][j]);
+   for(j=1;j<=ny+1;j++)
+    for(i=1;i<=nx+1;i++)
+       fprintf(fp,"%g\n",u2d[i+2][j+2][1]);
+   for(j=1;j<=ny+1;j++)
+    for(i=1;i<=nx+1;i++)
+       fprintf(up,"%g\n",u2d[i+2][j+2][2]/u2d[i+2][j+2][1]);
+   for(j=1;j<=ny+1;j++)
+    for(i=1;i<=nx+1;i++)
+       fprintf(vp,"%g\n",u2d[i+2][j+2][3]/u2d[i+2][j+2][1]);
+   for(j=1;j<=ny+1;j++)
+    for(i=1;i<=nx+1;i++)
+       fprintf(ep,"%g\n",u2d[i+2][j+2][4]/u2d[i+2][j+2][1]/Q); //energy (eV)
+   for(j=1;j<=ny+1;j++)
+    for(i=1;i<=nx+1;i++)
+       fprintf(Xp,"%g\n",E[i][j][0]);
+   for(j=1;j<=ny+1;j++)
+    for(i=1;i<=nx+1;i++)
+       fprintf(Yp,"%g\n",E[i][j][1]);
 
+// Save the file "variable.mesh"
+// =============================
+ fprintf(mp,"MeshVersionFormatted 1\n");
+ fprintf(mp,"Dimension %d\n",dim);
+ fprintf(mp,"Vertices\n%d\n",NUM_VERT);
+ for(j=1;j<=ny+1;j++)
+   for(i=1;i<=nx+1;i++)
+       fprintf(mp,"%g %g 0\n",(i-1.)*dx,(j-1.)*dy);
+ fprintf(mp,"Quadrilaterals\n%d\n",6*NUM_EXAHEDRA);
+ for(j=1;j<=ny;j++)
+  for(i=1;i<=nx;i++)
+     fprintf(mp,"%d %d %d %d 0\n",
+         i+(j-1)*(nx+1),i+1+(j-1)*(nx+1),
+         i+1+j*(nx+1),i+j*(nx+1)); // 1 2 4 3
+ }
 // Closure of files
 // ================
     fclose(fp);
