@@ -1,6 +1,6 @@
-/* updating.h -- This file is part of Archimedes release 0.0.1.
-   Archimedes is a simulator for Submicron 2D Silicon
-   Devices. It implements the Monte Carlo method
+/* updating.h -- This file is part of Archimedes release 0.0.3.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+   Devices. It implements the Monte Carlo method and MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -25,7 +25,7 @@
 
 // ######################################################
 // Created on 08 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 07 Oct.2004, Siracusa, J.M.Sellier
+// Last modif. : 05 Mar.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Updating of the macroscopic variables
@@ -53,6 +53,22 @@ updating(int model)
    if((TEMPO+DT)>=TF) DT=TF-TEMPO;
    TEMPO+=DT;
   }
+// Electron MEP Simulation
+// =======================
+  if(model==MEPE || model==MEPEH){
+   DT/=2.;
+   ParabMEP2D(nx,ny,dx,dy,0.475,1.0);
+   electron_relaxation_step();
+   DT*=2.;
+  }
+// Hole MEP Simulation
+// ===================
+  if(model==MEPH || model==MEPEH){
+   DT/=2.;
+   Hole_MEP2D(nx,ny,dx,dy,0.475,1.0);
+   Relaxation_Step_Hole();
+   DT*=2.;
+  }
 // Output on some usefull informations about the simulation
   printf("%5d   TIME = %10.4g  (picosec)\n",c,TEMPO*1.e12);
   if(MAXIMINI==1){
@@ -61,8 +77,14 @@ updating(int model)
     maxi=mini=0.;
     for(i=1;i<=nx+1;i++)
       for(j=1;j<=ny+1;j++){
+       if(Model_Number==MCE || Model_Number==MCEH){
         if(u2d[i][j][0]>=maxi) maxi=u2d[i][j][0];
         if(u2d[i][j][0]<=mini) mini=u2d[i][j][0];
+       }
+       if(Model_Number==MEPE || Model_Number==MEPEH){
+        if(u2d[i+2][j+2][0]>=maxi) maxi=u2d[i+2][j+2][0];
+        if(u2d[i+2][j+2][0]<=mini) mini=u2d[i+2][j+2][0];
+       }
       }
     printf("Max. Potential = %g\n",maxi);
     printf("Min. Potential = %g\n",mini);
@@ -89,8 +111,14 @@ updating(int model)
     mini=DDmax;
     for(i=1;i<=nx+1;i++)
       for(j=1;j<=ny+1;j++){
+       if(Model_Number==MCE || Model_Number==MCEH){
         if(u2d[i][j][1]>=maxi) maxi=u2d[i][j][1];
         if(u2d[i][j][1]<=mini) mini=u2d[i][j][1];
+       }
+       if(Model_Number==MEPE || Model_Number==MEPEH){
+        if(u2d[i+2][j+2][1]>=maxi) maxi=u2d[i+2][j+2][1];
+        if(u2d[i+2][j+2][1]<=mini) mini=u2d[i+2][j+2][1];
+       }
       }
     printf("Max. Density = %g\n",maxi);
     printf("Min. Density = %g\n",mini);
@@ -101,7 +129,6 @@ updating(int model)
     SaveOutputFiles(File_Format,c);
     printf("Output number %d has been saved\n",c);
   }
-
   if(fabs(TEMPO-TF)/fabs(TF)<SMALL){
 // Compute the various currents on the various defined contacts
     Compute_Currents();
